==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/instance/impl/LinkParticipationSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.instance.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.AssociationSet;
import io.ciera.tool.sql.ooaofooa.association.impl.AssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.instance.I_INSSet;
import io.ciera.tool.sql.ooaofooa.instance.LinkParticipation;
import io.ciera.tool.sql.ooaofooa.instance.LinkParticipationSet;
import io.ciera.tool.sql.ooaofooa.instance.LinkSet;
import io.ciera.tool.sql.ooaofooa.instance.impl.I_INSSetImpl;
import io.ciera.tool.sql.ooaofooa.instance.impl.LinkSetImpl;

import java.util.Arrays;
import java.util.List;


public class LinkParticipationSetImpl extends InstanceSet<LinkParticipationSet,LinkParticipation> implements LinkParticipationSet {

    // attributes
    @Override
    public void setInst_ID( UniqueId ref_Inst_ID ) throws XtumlException {
        for ( LinkParticipation linkparticipation : this ) linkparticipation.setInst_ID( ref_Inst_ID );
    }
    @Override
    public void setParticipation_ID( UniqueId m_Participation_ID ) throws XtumlException {
        for ( LinkParticipation linkparticipation : this ) linkparticipation.setParticipation_ID( m_Participation_ID );
    }
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( LinkParticipation linkparticipation : this ) linkparticipation.setRel_ID( ref_Rel_ID );
    }
    @Override
    public void setLabel( String m_Label ) throws XtumlException {
        for ( LinkParticipation linkparticipation : this ) linkparticipation.setLabel( m_Label );
    }


    // selections
    @Override
    public LinkSet R2901_is_origin_of_Link() throws XtumlException {
        LinkSet linkset = new LinkSetImpl();
        for ( LinkParticipation linkparticipation : this ) linkset.addAll( linkparticipation.R2901_is_origin_of_Link() );
        return linkset;
    }
    @Override
    public LinkSet R2902_is_destination_of_Link() throws XtumlException {
        LinkSet linkset = new LinkSetImpl();
        for ( LinkParticipation linkparticipation : this ) linkset.addAll( linkparticipation.R2902_is_destination_of_Link() );
        return linkset;
    }
    @Override
    public LinkSet R2903_is_associator_for_Link() throws XtumlException {
        LinkSet linkset = new LinkSetImpl();
        for ( LinkParticipation linkparticipation : this ) linkset.addAll( linkparticipation.R2903_is_associator_for_Link() );
        return linkset;
    }
    @Override
    public I_INSSet R2958_I_INS() throws XtumlException {
        I_INSSet i_insset = new I_INSSetImpl();
        for ( LinkParticipation linkparticipation : this ) i_insset.add( linkparticipation.R2958_I_INS() );
        return i_insset;
    }
    @Override
    public AssociationSet R2959_Association() throws XtumlException {
        AssociationSet associationset = new AssociationSetImpl();
        for ( LinkParticipation linkparticipation : this ) associationset.add( linkparticipation.R2959_Association() );
        return associationset;
    }


    @Override
    public LinkParticipation nullElement() {
        return LinkParticipationImpl.EMPTY_LINKPARTICIPATION;
    }

    @Override
    public LinkParticipationSet emptySet() {
      return new LinkParticipationSetImpl();
    }

    @Override
    public LinkParticipationSet value() {
        return this;
    }

    @Override
    public List<LinkParticipation> elements() {
        return Arrays.asList(toArray(new LinkParticipation[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/instance/impl/LinkParticipationSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.instance.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.AssociationSet;
import io.ciera.tool.sql.ooaofooa.association.impl.AssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.instance.I_INSSet;
import io.ciera.tool.sql.ooaofooa.instance.LinkParticipation;
import io.ciera.tool.sql.ooaofooa.instance.LinkParticipationSet;
import io.ciera.tool.sql.ooaofooa.instance.LinkSet;
import io.ciera.tool.sql.ooaofooa.instance.impl.I_INSSetImpl;
import io.ciera.tool.sql.ooaofooa.instance.impl.LinkSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class LinkParticipationSetImpl extends InstanceSet<LinkParticipationSet,LinkParticipation> implements LinkParticipationSet {

    public LinkParticipationSetImpl() {
    }

    public LinkParticipationSetImpl(Comparator<? super LinkParticipation> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setParticipation_ID( UniqueId m_Participation_ID ) throws XtumlException {
        for ( LinkParticipation linkparticipation : this ) linkparticipation.setParticipation_ID( m_Participation_ID );
    }
    @Override
    public void setInst_ID( UniqueId ref_Inst_ID ) throws XtumlException {
        for ( LinkParticipation linkparticipation : this ) linkparticipation.setInst_ID( ref_Inst_ID );
    }
    @Override
    public void setLabel( String m_Label ) throws XtumlException {
        for ( LinkParticipation linkparticipation : this ) linkparticipation.setLabel( m_Label );
    }
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( LinkParticipation linkparticipation : this ) linkparticipation.setRel_ID( ref_Rel_ID );
    }


    // selections
    @Override
    public LinkSet R2901_is_origin_of_Link() throws XtumlException {
        LinkSet linkset = new LinkSetImpl();
        for ( LinkParticipation linkparticipation : this ) linkset.addAll( linkparticipation.R2901_is_origin_of_Link() );
        return linkset;
    }
    @Override
    public LinkSet R2902_is_destination_of_Link() throws XtumlException {
        LinkSet linkset = new LinkSetImpl();
        for ( LinkParticipation linkparticipation : this ) linkset.addAll( linkparticipation.R2902_is_destination_of_Link() );
        return linkset;
    }
    @Override
    public LinkSet R2903_is_associator_for_Link() throws XtumlException {
        LinkSet linkset = new LinkSetImpl();
        for ( LinkParticipation linkparticipation : this ) linkset.addAll( linkparticipation.R2903_is_associator_for_Link() );
        return linkset;
    }
    @Override
    public I_INSSet R2958_I_INS() throws XtumlException {
        I_INSSet i_insset = new I_INSSetImpl();
        for ( LinkParticipation linkparticipation : this ) i_insset.add( linkparticipation.R2958_I_INS() );
        return i_insset;
    }
    @Override
    public AssociationSet R2959_Association() throws XtumlException {
        AssociationSet associationset = new AssociationSetImpl();
        for ( LinkParticipation linkparticipation : this ) associationset.add( linkparticipation.R2959_Association() );
        return associationset;
    }


    @Override
    public LinkParticipation nullElement() {
        return LinkParticipationImpl.EMPTY_LINKPARTICIPATION;
    }

    @Override
    public LinkParticipationSet emptySet() {
      return new LinkParticipationSetImpl();
    }

    @Override
    public LinkParticipationSet emptySet(Comparator<? super LinkParticipation> comp) {
      return new LinkParticipationSetImpl(comp);
    }

    @Override
    public LinkParticipationSet value() {
        return this;
    }

    @Override
    public List<LinkParticipation> elements() {
        return Arrays.asList(toArray(new LinkParticipation[0]));
    }

}
